# try:
#     import unittest2 as unittest
# except ImportError:
#     import unittest
#
# import time
# from datetime import datetime
# import os
# import logging
#
# from wia import Wia
# from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError
#
# class FunctionsTest(unittest.TestCase):
#     function_id = None
#
#     def test_functions_create(self):
#         wia = Wia()
#         wia.access_token = os.environ['device_secret_key']
#         wia.Stream.connect()
#         count = 0
#         while count <= 10:
#             time.sleep(0.5)
#             count += 1
#             if wia.Stream.connected:
#                 time.sleep(1)
#                 break
#         self.assertTrue(wia.Stream.connected)
#         def test_function(argument):
#             print(argument)
#         result = wia.Function.create(name='test_function_create', function=test_function)
#         self.__class__.test_id = result['id']
#         wia.Stream.disconnect()
#         count = 0
#         while count <= 10:
#             time.sleep(0.5)
#             count += 1
#             if not wia.Stream.connected:
#                 break
#         self.assertFalse(wia.Stream.connected)
#         wia.access_token = None
#
#     def test_functions_delete(self):
#         wia = Wia()
#         wia.access_token = os.environ['device_secret_key']
#         result = wia.Function.delete(self.__class__.test_id)
#         self.assertTrue(result)
#         wia.access_token = None
#
#     def test_functions_call(self):
#         wia = Wia()
#         wia.access_token = os.environ['device_secret_key']
#         def test_function_2(payload):
#             print(payload)
#         wia.Stream.connect()
#         count = 0
#         while count <= 10:
#             time.sleep(0.5)
#             count += 1
#             if wia.Stream.connected:
#                 time.sleep(1)
#                 break
#         self.assertTrue(wia.Stream.connected)
#         function_return = wia.Function.create(name='test_function_2', function=test_function_2)
#         wia.access_token = os.environ['user_secret_key']
#         wia.Function.call(device=os.environ['device_id'], func=function_return['id'], data={'arg1': 'Hello World!', 'arg2': 1000})
#         time.sleep(2)
#         wia.Function.call(device=os.environ['device_id'], func=function_return['id'])
#         time.sleep(2)
#         wia.Function.call(device=os.environ['device_id'], func=function_return['id'], data="Hello")
#         time.sleep(2)
#         wia.Function.call(device=os.environ['device_id'], func=function_return['id'], data=99)
#         time.sleep(2)
#         wia.Stream.disconnect()
#         count = 0
#         while count <= 10:
#             time.sleep(0.5)
#             count += 1
#             if not wia.Stream.connected:
#                 break
#         self.assertFalse(wia.Stream.connected)
#         wia.access_token = None
#
#     def test_functions_list(self):
#         wia = Wia()
#         wia.access_token = os.environ['org_secret_key']
#         list_return = wia.Function.list(device=os.environ['device_id'], limit=10, page=0)
#         self.assertTrue(list_return['functions'])
#         self.assertTrue(type(list_return['functions']) == list)
#         self.assertTrue(list_return['count'])
#         self.assertTrue(type(list_return['count']) == int)
#         wia.access_token = None
#
# if __name__ == '__main__':
#     unittest2.main()



try:
    import unittest2 as unittest
except ImportError:
    import unittest

import time
import os
import logging

from wia import Wia
from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError

#def on_connect():
    #print("on_connect called in test")

class StreamTest(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        wia = Wia()
        wia.access_token = os.environ['user_secret_key']

    def test_stream_connect(self):
        # wia.Stream.client.on_connect = on_connect
        wia = Wia()
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                break
        self.assertTrue(wia.Stream.connected)

if __name__ == '__main__':
    unittest2.main()



try:
    import unittest2 as unittest
except ImportError:
    import unittest

import logging
import time
import os

from wia import Wia
from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError

class LocationsTest(unittest.TestCase):
    def test_locations_publish(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connect)
        location = wia.Location.publish(latitude=50, longitude=60)
        self.assertTrue(location is not None)
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = None

    def test_locations_list(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Location.list(device=os.environ['device_id'], limit=10, page=0)
        self.__class__.locations_count = result['count']
        self.assertTrue('locations' in result)
        self.assertTrue(type(result['locations']) == list)
        self.assertTrue('count' in result)
        self.assertTrue(type(result['count']) == int)
        wia.access_token = None

    def test_locations_list_order_desc(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Location.list(device=os.environ['device_id'], limit=10, page=0, order='timestamp', sort='desc')
        locations_list = []
        #for location in result['locations']:
            #print location.timestamp
        wia.access_token = None

    def test_locations_list_order_asc(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Location.list(device=os.environ['device_id'], limit=10, page=0, order='timestamp', sort='asc')
        locations_list = []
        #for location in result['locations']:
            #print location.timestamp
        wia.access_token = None

    def test_locations_list_since_until(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        hour_ago = int((time.time())*1000 - 3600000)
        result = wia.Location.list(device=os.environ['device_id'], order='timestamp', sort='desc', since=hour_ago)
        self.assertTrue(type(result['count']) == int)
        result = {}
        result = wia.Location.list(device=os.environ['device_id'], order='timestamp', sort='desc', until=hour_ago)
        self.assertTrue(type(result['count']) == int)
        wia.access_token = None

    def test_locations_subscribe(self):
        wia = Wia()
        def location_function(payload):
            pass
        wia.access_token = os.environ['org_secret_key']
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)

        # subscribe to location
        wia.Location.subscribe(device=os.environ['device_id'], func=location_function)
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.subscribed)

        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)

        # publish location
        wia.access_token = os.environ['device_secret_key']

        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                break
        self.assertTrue(wia.Stream.connected)

        wia.Location.publish(longitude=60, latitude=50)

        wia.access_token = os.environ['org_secret_key']
        time.sleep(0.5)

        # unsubscribe from location
        initial_subscribe_count = wia.Stream.subscribed_count
        wia.Location.unsubscribe(device=os.environ['device_id'])
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed_count < initial_subscribe_count:
                break
        self.assertTrue(wia.Stream.subscribed_count < initial_subscribe_count)
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = None

    # ERROR TESTS
    def test_location_publish_not_authorized(self):
        wia = Wia()
        wia.Stream.disconnect()
        count = 0
        while count < 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = os.environ['org_secret_key']
        location = wia.Location.publish(latitude=10, longitude=10)
        self.assertIsInstance(location, WiaError)
        wia.access_token = None

    def test_location_publish_wrong_params(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        location = wia.Location.publish(name='fail')
        self.assertIsInstance(location, WiaError)
        wia.access_token = None

    def test_list_location_not_found(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Location.list(device='Unknown')
        self.assertIsInstance(result, WiaError)
        wia.access_token = None

if __name__ == '__main__':
    unittest2.main()



try:
    import unittest2 as unittest
except ImportError:
    import unittest

import time
from datetime import datetime
import os
import logging

from wia import Wia
from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError

class LogsTest(unittest.TestCase):
    def test_logs_publish_rest(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        result = wia.Log.publish(level='info', message='test1')
        self.assertTrue(result is not None)
        wia.access_token = None

    def test_logs_publish(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)
        result = wia.Log.publish(level='info', message='test_mqtt')
        self.assertTrue(result is not None)
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = None

    def test_logs_list(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Log.list(device=os.environ['device_id'], limit=10, page=0)
        self.assertTrue('logs' in result)
        self.assertTrue(type(result['logs']) == list)
        self.assertTrue('count' in result)
        self.assertTrue(type(result['count']) == int)
        wia.secret_key = None

    def test_logs_list_order_desc(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Log.list(device=os.environ['device_id'], limit=10, page=0, order='timestamp', sort='desc')
        logs_list = []
        #for log in result['logs']:
            #print log.timestamp
        wia.access_token = None

    def test_logs_list_order_asc(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Log.list(device=os.environ['device_id'], limit=10, page=0, order='timestamp', sort='asc')
        logs_list = []
        #for log in result['logs']:
            #print log.timestamp
        wia.access_token = None

    def test_logs_subscribe(self):
        wia = Wia()
        def logs_subscription_func(payload):
            pass
        wia.access_token = os.environ['org_secret_key']
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)

        # subscribe to log
        wia.Log.subscribe(device=os.environ['device_id'], func=logs_subscription_func)
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.subscribed)

        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)

        # publish log
        wia.access_token = os.environ['device_secret_key']

        wia.Stream.connect()
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)

        wia.Log.publish(level='info', message='test_subscribe')

        wia.access_token = os.environ['org_secret_key']
        time.sleep(0.5)

        # unsubscribe from log
        initial_subscribe_count = wia.Stream.subscribed_count
        wia.Log.unsubscribe(device=os.environ['device_id'])
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed_count < initial_subscribe_count:
                break
        self.assertTrue(wia.Stream.subscribed_count < initial_subscribe_count)

        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)

        wia.access_token = None

    # ERROR TESTS
    def test_publish_log_not_authorized(self):
        wia = Wia()
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = os.environ['org_secret_key']
        log = wia.Log.publish(level='fail', message='error')
        self.assertIsInstance(log, WiaError)
        wia.access_token = None

    def test_publish_log_wrong_params(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        log = wia.Log.publish(name='fail')
        self.assertIsInstance(log, WiaError)
        wia.access_token = None

    def test_list_log_not_found(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Log.list(device='Unknown')
        self.assertIsInstance(result, WiaError)
        wia.access_token = None

if __name__ == '__main__':
    unittest2.main()



try:
    import unittest2 as unittest
except ImportError:
    import unittest

import logging
import time
import os

from wia import Wia
from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError

class SensorsTest(unittest.TestCase):
    def test_sensors_publish_rest(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        sensor = wia.Sensor.publish(name='test_sensor_rest_1', data=99)
        self.assertTrue(sensor is not None)
        wia.access_token = None

    def test_sensors_publish(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)
        sensor = wia.Sensor.publish(name='test_sensor_mqtt', data=130)
        self.assertTrue(sensor is not None)
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = None

    def test_sensors_list(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Sensor.list(device=os.environ['device_id'], limit=10, page=0)
        #print('LIST', result)
        self.__class__.sensor_count = result['count']
        self.assertTrue('sensors' in result)
        self.assertTrue(type(result['sensors']) == list)
        self.assertTrue('count' in result)
        self.assertTrue(type(result['count']) == int)
        wia.access_token = None

    def test_sensors_list_name(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Sensor.list(device = os.environ['device_id'], name='test_sensor_1')
        self.assertFalse('error' in result)
        for sensor in result['sensors']:
            self.assertEqual('test_sensor_1', sensor.name)
        wia.access_token = None

    def test_sensors_list_since_until(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        hour_ago = int((time.time())*1000 - 3600000)
        result = wia.Sensor.list(device=os.environ['device_id'], order='timestamp', sort='desc', since=hour_ago)
        self.assertFalse('error' in result)
        self.assertTrue('count' in result)
        self.assertTrue(type(result['count']) == int)
        wia.access_token = None

    def test_sensors_subscribe(self):
        wia = Wia()
        def wildcard_function(payload):
            pass
        def specific_function(payload):
            pass
        wia.access_token = os.environ['org_secret_key']
        wia.Stream.connect()
        count = 0
        # waits for Stream to be connected
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)

        # subscirbe to sensor
        wia.Sensor.subscribe(device=os.environ['device_id'], func=wildcard_function)
        wia.Sensor.subscribe(device=os.environ['device_id'], name='subscribe_test_sensor', func=specific_function)
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.subscribed)

        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)

        # publish sensor data
        wia.access_token = os.environ['device_secret_key']

        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                break
        self.assertTrue(wia.Stream.connected)

        wia.Sensor.publish(name='subscribe_test_sensor', data=29)

        wia.access_token = os.environ['org_secret_key']
        time.sleep(0.5)

        count = 0
        initial_subscribe_count = wia.Stream.subscribed_count

        # unsubscribe from sensor
        wia.Sensor.unsubscribe(device=os.environ['device_id'])
        wia.Sensor.unsubscribe(device=os.environ['device_id'], name='subscribe_test_sensor')
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed_count < initial_subscribe_count:
                break
        self.assertTrue(wia.Stream.subscribed_count < initial_subscribe_count)
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = None

    # ERROR TESTING
    def test_publish_sensor_not_authorized(self):
        wia = Wia()
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                time.sleep(1)
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = os.environ['org_secret_key']
        sensor = wia.Sensor.publish(name='fail', data=401)
        self.assertIsInstance(sensor, WiaError)
        wia.access_token = None

    def test_publish_sensor_wrong_params(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        sensor = wia.Sensor.publish(abc='not_param')
        self.assertIsInstance(sensor, WiaError)
        wia.access_token = None

    def test_list_sensor_not_found(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Sensor.list(device='Unknown')
        self.assertIsInstance(result, WiaError)
        wia.access_token = None

if __name__ == '__main__':
    unittest2.main()



try:
    import unittest2 as unittest
except ImportError:
    import unittest

import time
import os
import logging

from wia import Wia
from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError

class CustomerTest(unittest.TestCase):

    # def test_customer_create(self):
    #     wia = Wia()
    #     wia.access_token = os.environ['org_secret_key']
    #     wia.app_key = os.environ['app_key']
    #     customer = wia.Customer.create(fullName='John Smith',
    #                                     email='socool@true.com')
    #     self.assertEqual(customer.fullName, 'Eric TheCoolest')
    #     self.assertEqual(customer.email, 'socool@true.com')
    #     self.__class__.test_id = customer.id
    #     wia.access_token = None
    #
    # def test_customer_retrieve(self):
    #     wia = Wia()
    #     wia.access_token = os.environ['org_secret_key']
    #     wia.app_key = os.environ['app_key']
    #     customer = wia.Customer.retrieve(self.__class__.test_id)
    #     self.assertEqual(customer.fullName, 'John Smith')
    #     wia.access_token = None
    #
    # def test_customer_delete(self):
    #     wia = Wia()
    #     wia.access_token = os.environ['org_secret_key']
    #     wia.app_key = os.environ['app_key']
    #     customer = wia.Customer.retrieve(self.__class__.test_id)
    #     self.assertTrue(customer.delete(customer.id))
    #     wia.access_token = None

    # def test_login(self):
    #     wia = Wia()
    #     wia.access_token = os.environ['org_secret_key']
    #     wia.app_key = os.environ['app_key']
    #     response = wia.Customer.login(username='different2@blachmanity.com',
    #                                     password='password2')
    #     print('log in', response)

    # ERROR TESTS
    def test_customer_create_not_authorized(self):
        wia = Wia()
        wia.access_token = os.environ['user_secret_key']
        customer = wia.Customer.create(fullName='miseraable fail', email='try@butfail.com')
        self.assertIsInstance(customer, WiaError)
        wia.access_token = None

    def test_customer_create_wrong_params(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        customer = wia.Customer.create(abc='Not a param')
        self.assertIsInstance(customer, WiaError)
        wia.access_token = None

    def test_customer_create_bad_params(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        customer = wia.Customer.create(fullName='1234', email='invalid')
        self.assertIsInstance(customer, WiaError)
        wia.access_token = None

    def test_customer_delete_not_found(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        customer = wia.Device.delete('oops')
        self.assertIsInstance(customer, WiaError)
        wia.access_token = None

    def test_customer_retrieve_not_found(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        customer = wia.Customer.retrieve('Unknown')
        self.assertIsInstance(customer, WiaError)
        wia.access_token = None

if __name__ == '__main__':
    unittest2.main()



try:
    import unittest2 as unittest
except ImportError:
    import unittest

import time
import os
import logging

from wia import Wia
from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError

class DeviceTest(unittest.TestCase):
    test_id = ''

    def test_public_org_create(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        device = wia.Device.create(name='johnDoe',serialNumber='test', public=True)
        self.__class__.test_id = device.id
        self.assertEqual(device.name, 'johnDoe')
        wia.access_token = None

    def test_user_create(self):
        wia = Wia()
        wia.access_token = os.environ['user_secret_key']
        device = wia.Device.create(name='janeDoe')
        time.sleep(1)
        self.assertEqual(device.name, 'janeDoe')
        id = device.id
        device = wia.Device.retrieve(id)
        self.assertTrue(device.delete(device.id))
        wia.access_token = None

    # retrieves device created in the first function in this page
    def test_retrieve(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        device = wia.Device.retrieve(self.__class__.test_id)
        self.assertEqual(device.name, 'johnDoe')
        self.assertTrue(device.delete(device.id))
        wia.access_token = None

    def test_update(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        test_device = wia.Device.create(name='johnDoe', public=True)
        device = wia.Device.retrieve(test_device.id)
        self.assertEqual(device.name, 'johnDoe')
        device = wia.Device.update(name="janeDoe", id=device.id)
        now_device = wia.Device.retrieve(device.id)
        self.assertEqual(now_device.name, 'janeDoe')
        self.assertTrue(now_device.delete(device.id))
        wia.access_token = None

    def test_delete(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        test_device = wia.Device.create(name='toBeDestroyed', public=True)
        test_device = wia.Device.retrieve(test_device.id)
        self.assertTrue(test_device.delete(test_device.id))
        wia.access_token = None

    def test_device_list(self):
        wia = Wia()
        wia.access_token = os.environ['user_secret_key']
        list_return = wia.Device.list(limit=20, page=0)
        self.assertTrue('devices' in list_return)
        self.assertTrue(type(list_return['devices']) == list)
        self.assertTrue('count' in list_return)
        self.assertTrue(type(list_return['count']) == int)
        wia.access_token = None

    def test_devices_list_order_desc(self):
        wia = Wia()
        wia.access_token = os.environ['user_secret_key']
        result = wia.Device.list(order='createdAt', sort='desc')
        devices_list = []
        #for device in result['devices']:
            #print device.createdAt
        wia.access_token = None

    def test_devices_list_order_asc(self):
        wia = Wia()
        wia.access_token = os.environ['user_secret_key']
        result = wia.Device.list(order='createdAt', sort='asc')
        devices_list = []
        #for device in result['devices']:
            #print device.createdAt
        wia.access_token = None

    def test_device_list_public(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        list_return = wia.Device.list(public=False)
        for device in list_return['devices']:
            self.assertFalse(device.public)
        list_return = wia.Device.list(public=True)
        for device in list_return['devices']:
            self.assertTrue(device.public)
        wia.access_token = None

    # ERROR TESTS
    def test_create_device_not_authorized(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        device = wia.Device.create(name='fail', public=True)
        self.assertIsInstance(device, WiaError)
        wia.access_token = None

    def test_create_device_invalid_params(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        device = wia.Device.create(name='fail', public='Oops')
        self.assertIsInstance(device, WiaError)
        wia.access_token = None

    def test_create_device_wrong_params(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        device = wia.Device.create(name='fail', data=100)
        self.assertIsInstance(device, WiaError)
        wia.access_token = None

    def test_device_delete_unknown(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        device = wia.Device.delete('nonexisting')
        self.assertIsInstance(device, WiaError)
        wia.access_token = None

    def test_device_retrieve_unknown(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        device = wia.Device.retrieve('dev_nonexisting')
        self.assertIsInstance(device, WiaError)
        wia.access_token = None

if __name__ == '__main__':
    unittest2.main()



try:
    import unittest2 as unittest
except ImportError:
    import unittest

import logging
import time
import os

from wia import Wia
from wia.error import WiaError, WiaValidationError, WiaUnauthorisedError, WiaForbiddenError, WiaNotFoundError

class EventsTest(unittest.TestCase):
    def test_events_publish_rest(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        event = wia.Event.publish(name='test_event_other_rest', data=130)
        #print event
        self.assertTrue(event.id is not None)
        wia.access_token = None

    def test_events_publish(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)
        result = wia.Event.publish(name='test_event_mqtt', data=130)
        self.assertTrue(result is not None)
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = None

    def test_events_publish_file(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        result = wia.Event.publish(name='test_event_other_filesud', data=1300, file=open('image.jpg', 'rb'))
        wia.access_token = None

    def test_device_org_retrieve(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)
        publish = wia.Event.publish(name='device_org_test_event', data=99)
        wia.access_token = os.environ['org_secret_key']
        response = wia.Device.retrieve(os.environ['device_id'])
        self.assertEqual(response.events['device_org_test_event']['name'], 'device_org_test_event')
        wia.access_token = None

    def test_events_list(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Event.list(device=os.environ['device_id'], limit=10, page=0)
        self.__class__.event_count = result['count']
        self.assertTrue('events' in result)
        self.assertTrue(type(result['events']) == list)
        self.assertTrue('count' in result)
        self.assertTrue(type(result['count']) == int)
        wia.access_token = None

    def test_events_list_order_desc(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Event.list(device=os.environ['device_id'], limit=10, page=0, order='timestamp', sort='desc')
        events_list = []
        #for event in result['events']:
            #print event.timestamp
        wia.access_token = None

    def test_events_list_order_asc(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Event.list(device=os.environ['device_id'], limit=10, page=0, order='timestamp', sort='asc')
        events_list = []
        #for event in result['events']:
            #print event.timestamp
        wia.access_token = None

    def test_events_list_name(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Event.list(device = os.environ['device_id'], name='test_event')
        for event in result['events']:
            self.assertEqual('test_event', event['name'])
        wia.access_token = None

    def test_events_list_since_until(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        hour_ago = int((time.time())*1000 - 3600000)
        result = wia.Event.list(device=os.environ['device_id'], order='timestamp', sort='desc', since=hour_ago)
        self.assertTrue(type(result['count']) == int)
        result = {}
        result = wia.Event.list(device=os.environ['device_id'], order='timestamp', sort='desc', until=hour_ago)
        self.assertTrue(type(result['count']) == int)
        wia.access_token = None

    def test_events_subscribe(self):
        wia = Wia()
        def wildcard_function(payload):
            pass
        def specific_function(payload):
            pass
        wia.access_token = os.environ['org_secret_key']
        wia.Stream.connect()
        count = 0
        # waits for Stream to be connected
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.connected)

        # subscirbe to event
        wia.Event.subscribe(device=os.environ['device_id'], func=wildcard_function)
        wia.Event.subscribe(device=os.environ['device_id'], name='subscribe_test_event', func=specific_function)
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed:
                time.sleep(1)
                break
        self.assertTrue(wia.Stream.subscribed)

        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)

        # publish event data
        wia.access_token = os.environ['device_secret_key']

        wia.Stream.connect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.connected:
                break
        self.assertTrue(wia.Stream.connected)

        wia.Event.publish(name='subscribe_test_event', data=97)

        wia.access_token = os.environ['org_secret_key']
        time.sleep(0.5)

        count = 0
        initial_subscribe_count = wia.Stream.subscribed_count
        #print(initial_subscribe_count)

        # unsubscribe from event
        wia.Event.unsubscribe(device=os.environ['device_id'])
        wia.Event.unsubscribe(device=os.environ['device_id'], name='subscribe_test_event')
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if wia.Stream.subscribed_count < initial_subscribe_count:
                break
        self.assertTrue(wia.Stream.subscribed_count < initial_subscribe_count)
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = None

    # ERROR TESTS
    def test_events_publish_rest_error(self):
        wia = Wia()
        wia.access_token = os.environ['device_secret_key']
        result = wia.Event.publish(abc='def')
        self.assertIsInstance(result, WiaError)
        wia.access_token = None

    def test_event_publish_not_authorized(self):
        wia = Wia()
        wia.Stream.disconnect()
        count = 0
        while count <= 10:
            time.sleep(0.5)
            count += 1
            if not wia.Stream.connected:
                time.sleep(1)
                break
        self.assertFalse(wia.Stream.connected)
        wia.access_token = os.environ['user_secret_key']
        event = wia.Event.publish(name='fail', data=100)
        self.assertIsInstance(event, WiaError)
        wia.access_token = None

    def test_event_publish_wrong_params(self):
        wia = Wia()
        wia.access_token = os.environ['user_secret_key']
        event = wia.Event.publish(abc='wrong_param')
        self.assertIsInstance(event, WiaError)
        wia.access_token = None

    def test_list_event_not_found(self):
        wia = Wia()
        wia.access_token = os.environ['org_secret_key']
        result = wia.Event.list(device='Unknown')
        self.assertIsInstance(result, WiaError)
        wia.access_token = None

if __name__ == '__main__':
    unittest.main()
